@@ -50,11 +50,8 @@ sub stc_build_scintilla_object {
 		$self->stc_defines,
 		( $Config{ptrsize} == 8 ) ? '-DWIN32 -DWIN64' : '-DWIN32',
 		'-o ' . $object_name,
-		'-O2',
-		'-Wall',
-		$object_name !~ /((Plat|Scintilla)WX|scintilla)\.o/
-		? '-Wno-missing-braces -Wno-char-subscripts'
-		: '',
+		'-O2 ',
+		'-Wall ',
 		'-MT' . $object_name,
 		'-MF' . $object_name . '.d',
 		'-MD -MP',
@@ -103,7 +100,7 @@ sub stc_build_xs {
 
 	$self->_run_command( \@cmd );
 
-	$self->log_info("    ExtUtils::Mksymlists Scintilla\n");
+	$self->log_info("Running Mkbootstrap for Wx::Scintilla\n");
 
 	require ExtUtils::Mksymlists;
 	ExtUtils::Mksymlists::Mksymlists(
@@ -126,11 +123,6 @@ sub stc_link_xs {
 	$perllib =~ s/^lib/-l/;
 	$perllib =~ s/\.a$//;
 
-	# if perl lib is MS link lib perl5xx.lib, we need to prefix fullpath
-	if ( $perllib =~ /\.lib$/i ) {
-		$perllib = $Config{archlibexp} . '/CORE/' . $perllib;
-	}
-
 	my @cmd = (
 		Alien::wxWidgets->linker,
 		Alien::wxWidgets->link_flags,
